@@ -5,15 +5,17 @@ CodinGame API Wrapper
 Basic wrapper for the undocumented CodinGame API.
 """
 
-from collections import namedtuple
+from typing import NamedTuple
 
-VersionInfo = namedtuple("VersionInfo", "major minor micro releaselevel serial")
+VersionInfo = NamedTuple(
+    "VersionInfo", major=int, minor=int, micro=int, releaselevel=str, serial=int
+)
 
-version_info = VersionInfo(major=0, minor=3, micro=1, releaselevel=".post", serial=0)
+version_info = VersionInfo(major=0, minor=3, micro=5, releaselevel="", serial=0)
 
 __title__ = "codingame"
 __author__ = "takos22"
-__version__ = "0.3.1.post0"
+__version__ = "0.3.5"
 
 __all__ = [
     "Client",
@@ -24,10 +26,11 @@ __all__ = [
     "CodinGameAPIError",
     "CodinGamerNotFound",
     "ClashOfCodeNotFound",
+    "LoginRequired",
 ]
 
 from .client import Client
 from .codingamer import CodinGamer
 from .clash_of_code import ClashOfCode, Player
 from .notification import Notification
-from .exceptions import CodinGameAPIError, CodinGamerNotFound, ClashOfCodeNotFound
+from .exceptions import CodinGameAPIError, CodinGamerNotFound, ClashOfCodeNotFound, LoginRequired
