@@ -1,7 +1,7 @@
 import requests
 import re
 
-from typing import List, Optional
+from typing import List, Optional, Iterator
 
 from .codingamer import CodinGamer
 from .clash_of_code import ClashOfCode
@@ -21,7 +21,8 @@ class Client:
             If the client is logged in as a CodinGamer.
 
         codingamer: Optional[:class:`CodinGamer`]
-            The CodinGamer that is logged in through the client. ``None`` if the client isn't logged in.
+            The CodinGamer that is logged in through the client.
+            ``None`` if the client isn't logged in.
     """
 
     _CODINGAMER_HANDLE_REGEX = re.compile(r"[0-9a-f]{32}[0-9]{7}")
@@ -30,7 +31,7 @@ class Client:
     logged_in: bool
     codingamer: Optional[CodinGamer]
 
-    def __init__(self, email=None, password=None):
+    def __init__(self, email: str = None, password: str = None):
         self._session = requests.Session()
 
         self.logged_in = False
@@ -53,7 +54,8 @@ class Client:
         Raises
         ------
             :exc:`ValueError`
-                Error with the login (empty email, empty password, wrong email format, incorrect password, etc).
+                Error with the login (empty email, empty password,
+                wrong email format, incorrect password, etc).
 
         Returns
         --------
@@ -71,26 +73,32 @@ class Client:
         if "id" in json and "message" in json:
             raise ValueError(f"{json['id']}: {json['message']}")
         self.logged_in = True
-        self.codingamer = CodinGamer(client=self, **r.json()["codinGamer"])
+        self.codingamer = CodinGamer(client=self, **json["codinGamer"])
         return self.codingamer
 
     @validate_args
-    def get_codingamer(self, codingamer_handle: str) -> CodinGamer:
-        """Get a CodinGamer from his public handle.
+    def get_codingamer(self, codingamer) -> CodinGamer:
+        """Get a CodinGamer from their public handle, their id or from their username.
+
+        .. note::
+            ``codingamer`` can be the public handle, the id or the username. Using the public handle
+            or the id is reccomended because it won't change even if the codingamer changes
+            their username.
+
+            The public handle is a 39 character long hexadecimal string that represents the user.
+            Regex of a public handle: ``[0-9a-f]{32}[0-9]{7}``
+
+            The id is a 7 number long integer
 
         Parameters
         -----------
-            codingamer_handle: :class:`str`
-                The CodinGamer's public handle.
-                39 character long hexadecimal string (regex: ``[0-9a-f]{32}[0-9]{7}``).
+            codingamer: :class:`str`
+                The CodinGamer's public handle, id or username.
 
         Raises
         ------
-            :exc:`ValueError`
-                The CodinGamer handle isn't in the good format.
-
             :exc:`.CodinGamerNotFound`
-                The CodinGamer with the given public handle isn't found.
+                The CodinGamer with the given public handle, id or username isn't found.
 
         Returns
         --------
@@ -98,16 +106,29 @@ class Client:
                 The CodinGamer.
         """
 
-        if not self._CODINGAMER_HANDLE_REGEX.match(codingamer_handle):
-            raise ValueError(
-                f"CodinGamer handle {codingamer_handle!r} isn't in the good format "
-                "(regex: [0-9a-f]{{32}}[0-9]{{7}})."
-            )
+        if type(codingamer) == int:
+            r = self._session.post(Endpoints.CodinGamer_id, json=[codingamer])
+            json = r.json()
+            if "id" in json and json["id"] == 404:
+                raise CodinGamerNotFound(f"No CodinGamer with id {codingamer!r}")
+            return CodinGamer(client=self, **json)
 
-        r = self._session.post(Endpoints.CodinGamer, json=[codingamer_handle])
-        if r.json() is None:
-            raise CodinGamerNotFound(f"No CodinGamer with handle {codingamer_handle!r}")
-        return CodinGamer(client=self, **r.json()["codingamer"])
+        if not self._CODINGAMER_HANDLE_REGEX.match(codingamer):
+            r = self._session.post(Endpoints.Search, json=[codingamer, "en", None])
+            search: List[dict] = r.json()
+            users = [query for query in search if query["type"] == "USER"]
+            if users:
+                handle = users[0]["id"]
+            else:
+                raise CodinGamerNotFound(f"No CodinGamer with username {codingamer!r}")
+        else:
+            handle = codingamer
+
+        r = self._session.post(Endpoints.CodinGamer, json=[handle])
+        json = r.json()
+        if json is None:
+            raise CodinGamerNotFound(f"No CodinGamer with handle {handle!r}")
+        return CodinGamer(client=self, **json["codingamer"])
 
     @validate_args
     def get_clash_of_code(self, clash_of_code_handle: str) -> ClashOfCode:
@@ -135,14 +156,30 @@ class Client:
 
         if not self._CLASH_OF_CODE_HANDLE_REGEX.match(clash_of_code_handle):
             raise ValueError(
-                f"CodinGamer handle {clash_of_code_handle!r} isn't in the good format "
-                "(regex: [0-9]{{7}}[0-9a-f]{{32}})."
+                f"Clash of Code handle {clash_of_code_handle!r} isn't in the good format "
+                "(regex: [0-9]{7}[0-9a-f]{32})."
             )
 
         r = self._session.post(Endpoints.ClashOfCode, json=[clash_of_code_handle])
-        if r.json() is None:
-            raise ClashOfCodeNotFound(f"No CodinGamer with handle {clash_of_code_handle!r}")
-        return ClashOfCode(client=self, **r.json())
+        json = r.json()
+        if "id" in json and "message" in json:
+            raise ClashOfCodeNotFound(f"No Clash of Code with handle {clash_of_code_handle!r}")
+        return ClashOfCode(client=self, **json)
+
+    def get_pending_clash_of_code(self) -> Optional[ClashOfCode]:
+        """Get a pending Clash of Code.
+
+        Returns
+        --------
+            Optional[:class:`ClashOfCode`]
+                The pending ClashOfCode if there's one or ``None``.
+        """
+
+        r = self._session.post(Endpoints.ClashOfCode_pending, json=[])
+        json = r.json()
+        if len(json) == 0:
+            return None
+        return ClashOfCode(client=self, **json[0])
 
     @property
     def language_ids(self) -> List[str]:
@@ -156,8 +193,24 @@ class Client:
             return self._language_ids
 
     @property
-    def notifications(self):
-        """List[:class:`Notification`]: List of unseen notifications."""
+    def notifications(self) -> Iterator[Notification]:
+        """Get all the unseen notifications of the Client.
+
+        You need to be logged in to get notifications or else a :exc:`LoginRequired` will be raised.
+
+        .. note::
+            This property is a generator.
+
+        Raises
+        ------
+            :exc:`LoginRequired`
+                The Client needs to log in. See :meth:`login`.
+
+        Yields
+        -------
+            :class:`Notification`
+                The Notification.
+        """
 
         if not self.logged_in:
             raise LoginRequired()
