@@ -13,5 +13,5 @@ class ClashOfCodeNotFound(CodinGameAPIError):
 
 class LoginRequired(CodinGameAPIError):
     """Raised when an action requires the client to log in."""
-    def __init__(self, message=None):
+    def __init__(self, message: str = None):
         super().__init__(message or "You must be logged in to perform this action.")
